@@ -13,7 +13,7 @@ use XSLoader;
 use Nana::Token;
 use Nana::Node;
 
-our $VERSION='0.17';
+our $VERSION='0.18';
 
 XSLoader::load('Nana::Parser', $VERSION);
 
@@ -399,6 +399,12 @@ rule('statement', [
         my $c = shift;
         ($c, my $block) = jump_statement($c)
             or return;
+        if ($c =~ /^(\s*|[^\n]+#[^\n]+)\n/) {
+            # say()
+            # if 1 {
+            # }
+            return ($c, $block);
+        }
         my ($used, $token_id) = _token_op($c);
         if ($token_id == TOKEN_IF) {
             # foo if bar
